settings = {
    'css': {
        'all': (
            'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css',
        )
    },
    'options': {
        'theme': 'bootstrap3',
        'iconlib': 'bootstrap3',
        'no_additional_properties': True,
    }
}


"""
The default configuration can be overriten in django settings:
To a better undestanding on this options plese refer to: https://github.com/jdorn/json-editor#options
"""

# JSONSCHEMAFORM = {
#     'css': {
#         'all': (
#             'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css',
#         )
#     },
#     'options': {
#         'ajax': False,
#         'disable_array_add': False,
#         'disable_array_delete': False,
#         'disable_array_reorder': False,
#         'disable_collapse': False,
#         'disable_edit_json': False,
#         'disable_properties': False,
#         'form_name_root': 'root',
#         'iconlib': None,
#         'no_additional_properties': False,
#         'refs': {},
#         'required_by_default': False,
#         'keep_oneof_values': True,
#         'schema': {},
#         'show_errors': "interaction",
#         'startval': None,
#         'template': 'default',
#         'theme': 'html',
#         'display_required_only': False
#     }
# }
